@@ -334,7 +334,7 @@ gchar ** asCStringArray(USER_OBJECT_ svec);
 #define asCRaw(s_raw) (GET_LENGTH(s_raw) ? RAW(s_raw)[0] : 0)
 #define asCNumeric(s_num) (GET_LENGTH(s_num) ? REAL(s_num)[0] : 0)
 
-gchar * asCString(USER_OBJECT_ s_str);
+const gchar * asCString(USER_OBJECT_ s_str);
 gchar asCCharacter(USER_OBJECT_ s_char);
 
 #define asRLogical ScalarLogical
@@ -388,6 +388,7 @@ GError *asCGError(USER_OBJECT_ s_error);
 
 /******* GObject structure conversion *********/
 int R_setGValueFromSValue(GValue *val, USER_OBJECT_ sval);
+USER_OBJECT_ R_setGValueForProperty(GValue *value, GObjectClass *class, const gchar *property_name, USER_OBJECT_ s_value);
 GValue* createGValueFromSValue(USER_OBJECT_ sval);
 gboolean initGValueFromSValue(USER_OBJECT_ sval, GValue *raw);
 gboolean initGValueFromVector(USER_OBJECT_ sval, gint n, GValue *raw);
@@ -472,10 +473,11 @@ USER_OBJECT_ retByVal(USER_OBJECT_ retval, ...);
 /* generic callback stuff */
 
 typedef struct {
-    USER_OBJECT_ function;
-    USER_OBJECT_ data;
-    Rboolean     useData;
-	Rboolean	 userDataFirst;
+  USER_OBJECT_ function;
+  USER_OBJECT_ data;
+  Rboolean     useData;
+  Rboolean     userDataFirst;
+  gpointer     extra; /* some C-level user data */
 } R_CallbackData;
 
 R_CallbackData *R_createCBData(USER_OBJECT_ s_func, USER_OBJECT_ s_data);
@@ -499,6 +501,17 @@ USER_OBJECT_ R_getGObjectProps(USER_OBJECT_ sobj, USER_OBJECT_ argNames);
 void GSListFreeStrings(GSList *gslist);
 void GListFreeStrings(GList *glist);
 
+void transformDoubleString(const GValue *src, GValue *dst);
+void transformIntString(const GValue *src, GValue *dst);
+void transformBooleanString(const GValue *src, GValue *dst);
+
+/* GSeekType enum runtime type info support (needed by GIO) */
+
+#define G_TYPE_SEEK_TYPE (g_seek_type_get_type ())
+GType g_seek_type_get_type (void) G_GNUC_CONST;
+#define G_TYPE_IO_CONDITION (g_io_condition_get_type ())
+GType g_io_condition_get_type (void) G_GNUC_CONST;
+
 /* do this by name, so that it is resolved at runtime, simplifying header dependencies */
 #if GLIB_CHECK_VERSION(2,10,0)
 #define UNOWNED_TYPE_NAME "GInitiallyUnowned"
